#
# spec file for package ghc-soap
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name soap
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.3.5
Release:        lp150.1.7
Summary:        SOAP client tools
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-configurator-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-iconv-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-xml-conduit-writer-devel
BuildRequires:  ghc-xml-types-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Tools to build SOAP clients using xml-conduit.

A mildly-complicated example:

> import Network.SOAP > import Network.SOAP.Transport.HTTP > > import
Text.XML.Writer > import Text.XML.Stream.Parse as Parse > import Data.Text
(Text) > import qualified Data.Text as T > > main :: IO () > main = do > --
Initial one-time preparations. > transport <- initTransport
"http://example.com/soap/endpoint" id (iconv "cp-1251") > > -- Making queries >
activeStaff <- listStaff transport True > print activeStaff > > data Person =
Person Text Int deriving Show > > listStaff :: Transport -> Bool -> IO [Person]
> listStaff t active = invokeWS t "urn:dummy:listStaff" () body parser > where
> body = element "request" $ element "listStaff" $ do > element "active" active
> element "order" $ T.pack "age" > element "limit" (10 :: Int) > > parser =
StreamParser $ force "no people" $ tagNoAttr "people" $ Parse.many parsePerson
> > parsePerson = tagName "person" (requireAttr "age") $ age -> do > name <-
Parse.content > return $ Person name (read . T.unpack $ age)

Notice: to invoke HTTPS services you need to initialize a transport from
soap-tls or soap-openssl.

Full examples available at source repo:
<https://bitbucket.org/dpwiz/haskell-soap/src/HEAD/soap/examples/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc changelog

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.2.3.5.
* Mon Dec 19 2016 psimons@suse.com
- Update to version 0.2.3.3 with cabal2obs.
* Tue Nov 29 2016 psimons@suse.com
- Update to version 0.2.3.2 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.2.3.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.3.0 revision 0 with cabal2obs.
